==> xoops-2.0.4-lang-ja-eucjp.zip: xoops-2.0.4-lang-ja-eucjp/html/language/japanese/global.php <==
<?php

//%%%%%%	File Name mainfile.php 	%%%%%
define('_PLEASEWAIT','Ф餯Ԥ');
define('_FETCHING','Loading...');
define('_TAKINGBACK','ξؤޤ....');
define('_LOGOUT','');
define('_SUBJECT','ɽ');
define('_MESSAGEICON','');
define('_COMMENTS','');
define('_POSTANON','ƿ̾');
define('_DISABLESMILEY','饢̵');
define('_DISABLEHTML','HTML̵');
define('_PREVIEW','ץӥ塼');

define('_GO','');
define('_NESTED','ͥɽ');
define('_NOCOMMENTS','ɽ');
define('_FLAT','եåɽ');
define('_THREADED','åɽ');
define('_OLDESTFIRST','ŤΤ');
define('_NEWESTFIRST','Τ');
define('_MORE','ä...');
define("_MULTIPAGE","<span style='color:red;'>[pagebreak]</span>ʸ˵뤳Ȥǥڡڤ뤳ȤǤޤ");
define('_IFNOTRELOAD','ڡưŪ˹ʤ<a href="%s"></a>򥯥åƤ');
define('_WARNINSTALL2','աե%sо¸ߤޤ󥹥ȡ봰λɬƤ');
define('_WARNINWRITEABLE','աե%sؤν񤭹ߤǽȤʤäƤޤΥեΥѡߥåѹƤ');

//%%%%%%	File Name themeuserpost.php 	%%%%%
define('_POSTEDBY','Ƽԡ'); // Posted date
define('_PROFILE','ץե');
define('_VISITWEBSITE','ۡڡ');
define('_SENDPMTO','%s˥ץ饤١ȥå롣');
define('_SENDEMAILTO','%s˥᡼롣');
define('_ADD','ɲ');
define('_REPLY','ֿ');
define('_DATE','');

//%%%%%%	File Name admin_functions.php 	%%%%%
define('_MAIN','ȥå');
define('_MANUAL','ޥ˥奢');
define('_INFO','С');
define('_CPHOME','˥塼');
define('_YOURHOME','ۡڡ');

//%%%%%%	File Name misc.php (who's-online popup)	%%%%%
define('_WHOSONLINE','饤'); 
define('_GUESTS', '');
define('_MEMBERS', 'Ͽ桼');
define('_ONLINEPHRASE','<b>%s</b> ͤΥ桼ߥ饤Ǥ');
define('_ONLINEPHRASEX','<b>%s</b> ͤΥ桼 <b>%s</b> 򻲾ȤƤޤ');
define('_CLOSE','Ĥ');  // Close window

//%%%%%%	File Name module.textsanitizer.php 	%%%%%
define('_QUOTEC','ѡ');

//%%%%%%	File Name admin.php 	%%%%%
define('_NOPERM','ΥꥢؤΥϵĤƤޤ');

//%%%%%		Common Phrases		%%%%%
define('_NO','');
define('_YES','Ϥ');
define('_EDIT','Խ');
define('_DELETE','');
define('_SUBMIT','');
define('_MODULENOEXIST','򤵤줿ڡ¸ߤޤ');
define('_ALIGN','');
define('_LEFT','');
define('_CENTER','');
define('_RIGHT','');
define('_FORM_ENTER', '%sϤƤ');
// %s represents file name
define('_MUSTWABLE','ե %s ؤν񤭹߸¤뤫ɤǧƤ');

define('_PREFERENCES', '');
define('_VERSION', 'С');
define('_DESCRIPTION', '');
define('_ERRORS', '顼');
define('_NONE', 'ʤ');
define('_ON','');
define('_READS','ҥå');
define('_WELCOMETO','%sؤ褦');
define('_SEARCH','');
define('_ALL', '٤');
define('_TITLE', '̾');      //-no use
define('_OPTIONS', 'ץ');
define('_QUOTE', '');     //-no use
define('_LIST', '');
define('_LOGIN','');
define('_USERNAME','桼̾: ');
define('_PASSWORD','ѥ: ');
define('_SELECT','');
define('_IMAGE','');
define('_SEND','');
define('_CANCEL','󥻥');
define('_ASCENDING','');
define('_DESCENDING','߽');
define('_BACK', '');

/* Image manager */
define('_IMGMANAGER','᡼ޥͥ㡼');
define('_NUMIMAGES', '%s ');
define('_ADDIMAGE','եɲ');
define('_IMAGENAME','̾:');
define('_IMGMAXSIZE','åץɤĤե륵(KB):');
define('_IMGMAXWIDTH','åץɤĤβʥԥ:');
define('_IMGMAXHEIGHT','åץɤĤι⤵ʥԥ:');
define('_IMAGECAT','ƥ:');
define('_IMAGEFILE','ե̾:');
define('_IMGWEIGHT','᡼ޥͥ㡼Ǥɽ:');
define('_IMGDISPLAY','βɽ');
define('_IMAGEMIME','MIME:');
define('_FAILFETCHIMG', 'åץɥե %s ǤޤǤ');
define('_FAILSAVEIMG', 'ե %s ǡ١˳ǼǤޤǤ');
define('_NOCACHE', 'åʤ');
define('_CLONE', 'ʣ');



//%%%%%	File Name class/xoopsform/formmatchoption.php 	%%%%%
define('_STARTSWITH', '');
define('_ENDSWITH', '');
define('_MATCHES', '');
define('_CONTAINS', 'ñޤ');

//%%%%%%	File Name commentform.php 	%%%%%
define('_REGISTER','Ͽ');

//%%%%%%	File Name xoopscodes.php 	%%%%%
define('_SIZE','礭');  // font size
define('_FONT','ե');  // font family
define('_COLOR','');  // font color
define('_EXAMPLE','ץ');
define('_ENTERURL','󥯤ȤURLϤƤ');
define('_ENTERWEBTITLE','̾ϤƤ');
define('_ENTERIMGURL','եURLϤƤ');
define('_ENTERIMGPOS','ե֤Ƥ');
define('_IMGPOSRORL','RפޤϡrפϤȱ¦ˡLפޤϡlפϤȺ¦ɽޤꤷʤ϶ˤƤ');
define('_ERRORIMGPOS','Ϥޤ󡣲ե֤Ƥ');
define('_ENTEREMAIL','󥯤᡼륢ɥ쥹ϤƤ');
define('_ENTERCODE','ץॳɤϤƤ');
define('_ENTERQUOTE','ѤʸϤƤ');
define('_ENTERTEXTBOX','ƥȥܥåϤƤ');
define('_ALLOWEDCHAR','Хȿ');
define('_CURRCHAR','ߤΥХȿ');
define('_PLZCOMPLETE','ɽꤪӥåʸƤ');
define('_MESSAGETOOLONG','åʸĹޤ');

//%%%%%		TIME FORMAT SETTINGS   %%%%%

define("_DATESTRING","Y-n-j G:i:s");
define("_MEDIUMDATESTRING","Y-n-j G:i");
define("_SHORTDATESTRING","Y-n-j");

define('_SECOND', '1');
define('_SECONDS', '%s');
define('_MINUTE', '1ʬ');
define('_MINUTES', '%sʬ');
define('_HOUR', '1');
define('_HOURS', '%s');
define('_DAY', '1');
define('_DAYS', '%s');
define('_WEEK', '1');
define('_MONTH', '1');

//%%%%%		LANGUAGE SPECIFIC SETTINGS   %%%%%
define('_CHARSET', 'EUC-JP');
define('_LANGCODE', 'ja');

// change 0 to 1 if this language is a multi-bytes language
define('XOOPS_USE_MULTIBYTES', '1');
?>

==> xoops-2.0.5-lang-ja-eucjp.zip: xoops-2.0.5-lang-ja-eucjp/html/language/japanese/global.php <==
<?php

//%%%%%%	File Name mainfile.php 	%%%%%
define('_PLEASEWAIT','Ф餯Ԥ');
define('_FETCHING','Loading...');
define('_TAKINGBACK','ξؤޤ....');
define('_LOGOUT','');
define('_SUBJECT','ɽ');
define('_MESSAGEICON','');
define('_COMMENTS','');
define('_POSTANON','ƿ̾');
define('_DISABLESMILEY','饢̵');
define('_DISABLEHTML','HTML̵');
define('_PREVIEW','ץӥ塼');

define('_GO','');
define('_NESTED','ͥɽ');
define('_NOCOMMENTS','ɽ');
define('_FLAT','եåɽ');
define('_THREADED','åɽ');
define('_OLDESTFIRST','ŤΤ');
define('_NEWESTFIRST','Τ');
define('_MORE','ä...');
define("_MULTIPAGE","<span style='color:red;'>[pagebreak]</span>ʸ˵뤳Ȥǥڡڤ뤳ȤǤޤ");
define('_IFNOTRELOAD','ڡưŪ˹ʤ<a href="%s"></a>򥯥åƤ');
define('_WARNINSTALL2','աե%sо¸ߤޤ󥹥ȡ봰λɬƤ');
define('_WARNINWRITEABLE','աե%sؤν񤭹ߤǽȤʤäƤޤΥեΥѡߥåѹƤ');

//%%%%%%	File Name themeuserpost.php 	%%%%%
define('_POSTEDBY','Ƽԡ'); // Posted date
define('_PROFILE','ץե');
define('_VISITWEBSITE','ۡڡ');
define('_SENDPMTO','%s˥ץ饤١ȥå롣');
define('_SENDEMAILTO','%s˥᡼롣');
define('_ADD','ɲ');
define('_REPLY','ֿ');
define('_DATE','');

//%%%%%%	File Name admin_functions.php 	%%%%%
define('_MAIN','ȥå');
define('_MANUAL','ޥ˥奢');
define('_INFO','С');
define('_CPHOME','˥塼');
define('_YOURHOME','ۡڡ');

//%%%%%%	File Name misc.php (who's-online popup)	%%%%%
define('_WHOSONLINE','饤'); 
define('_GUESTS', '');
define('_MEMBERS', 'Ͽ桼');
define('_ONLINEPHRASE','<b>%s</b> ͤΥ桼ߥ饤Ǥ');
define('_ONLINEPHRASEX','<b>%s</b> ͤΥ桼 <b>%s</b> 򻲾ȤƤޤ');
define('_CLOSE','Ĥ');  // Close window

//%%%%%%	File Name module.textsanitizer.php 	%%%%%
define('_QUOTEC','ѡ');

//%%%%%%	File Name admin.php 	%%%%%
define('_NOPERM','ΥꥢؤΥϵĤƤޤ');

//%%%%%		Common Phrases		%%%%%
define('_NO','');
define('_YES','Ϥ');
define('_EDIT','Խ');
define('_DELETE','');
define('_SUBMIT','');
define('_MODULENOEXIST','򤵤줿ڡ¸ߤޤ');
define('_ALIGN','');
define('_LEFT','');
define('_CENTER','');
define('_RIGHT','');
define('_FORM_ENTER', '%sϤƤ');
// %s represents file name
define('_MUSTWABLE','ե %s ؤν񤭹߸¤뤫ɤǧƤ');

define('_PREFERENCES', '');
define('_VERSION', 'С');
define('_DESCRIPTION', '');
define('_ERRORS', '顼');
define('_NONE', 'ʤ');
define('_ON','');
define('_READS','ҥå');
define('_WELCOMETO','%sؤ褦');
define('_SEARCH','');
define('_ALL', '٤');
define('_TITLE', '̾');      //-no use
define('_OPTIONS', 'ץ');
define('_QUOTE', '');     //-no use
define('_LIST', '');
define('_LOGIN','');
define('_USERNAME','桼̾: ');
define('_PASSWORD','ѥ: ');
define('_SELECT','');
define('_IMAGE','');
define('_SEND','');
define('_CANCEL','󥻥');
define('_ASCENDING','');
define('_DESCENDING','߽');
define('_BACK', '');
define('_NOTITLE', '̵');

/* Image manager */
define('_IMGMANAGER','᡼ޥͥ㡼');
define('_NUMIMAGES', '%s ');
define('_ADDIMAGE','եɲ');
define('_IMAGENAME','̾:');
define('_IMGMAXSIZE','åץɤĤե륵(KB):');
define('_IMGMAXWIDTH','åץɤĤβʥԥ:');
define('_IMGMAXHEIGHT','åץɤĤι⤵ʥԥ:');
define('_IMAGECAT','ƥ:');
define('_IMAGEFILE','ե̾:');
define('_IMGWEIGHT','᡼ޥͥ㡼Ǥɽ:');
define('_IMGDISPLAY','βɽ');
define('_IMAGEMIME','MIME:');
define('_FAILFETCHIMG', 'åץɥե %s ǤޤǤ');
define('_FAILSAVEIMG', 'ե %s ǡ١˳ǼǤޤǤ');
define('_NOCACHE', 'åʤ');
define('_CLONE', 'ʣ');



//%%%%%	File Name class/xoopsform/formmatchoption.php 	%%%%%
define('_STARTSWITH', '');
define('_ENDSWITH', '');
define('_MATCHES', '');
define('_CONTAINS', 'ñޤ');

//%%%%%%	File Name commentform.php 	%%%%%
define('_REGISTER','Ͽ');

//%%%%%%	File Name xoopscodes.php 	%%%%%
define('_SIZE','礭');  // font size
define('_FONT','ե');  // font family
define('_COLOR','');  // font color
define('_EXAMPLE','ץ');
define('_ENTERURL','󥯤ȤURLϤƤ');
define('_ENTERWEBTITLE','̾ϤƤ');
define('_ENTERIMGURL','եURLϤƤ');
define('_ENTERIMGPOS','ե֤Ƥ');
define('_IMGPOSRORL','RפޤϡrפϤȱ¦ˡLפޤϡlפϤȺ¦ɽޤꤷʤ϶ˤƤ');
define('_ERRORIMGPOS','Ϥޤ󡣲ե֤Ƥ');
define('_ENTEREMAIL','󥯤᡼륢ɥ쥹ϤƤ');
define('_ENTERCODE','ץॳɤϤƤ');
define('_ENTERQUOTE','ѤʸϤƤ');
define('_ENTERTEXTBOX','ƥȥܥåϤƤ');
define('_ALLOWEDCHAR','Хȿ');
define('_CURRCHAR','ߤΥХȿ');
define('_PLZCOMPLETE','ɽꤪӥåʸƤ');
define('_MESSAGETOOLONG','åʸĹޤ');

//%%%%%		TIME FORMAT SETTINGS   %%%%%

define("_DATESTRING","Y-n-j G:i:s");
define("_MEDIUMDATESTRING","Y-n-j G:i");
define("_SHORTDATESTRING","Y-n-j");

define('_SECOND', '1');
define('_SECONDS', '%s');
define('_MINUTE', '1ʬ');
define('_MINUTES', '%sʬ');
define('_HOUR', '1');
define('_HOURS', '%s');
define('_DAY', '1');
define('_DAYS', '%s');
define('_WEEK', '1');
define('_MONTH', '1');

//%%%%%		LANGUAGE SPECIFIC SETTINGS   %%%%%
define('_CHARSET', 'EUC-JP');
define('_LANGCODE', 'ja');

// change 0 to 1 if this language is a multi-bytes language
define('XOOPS_USE_MULTIBYTES', '1');

function xoops_language_trim($text)
{
	if (function_exists('mb_convert_kana')) {
		$text = mb_convert_kana($text, 's');
	}
	$text = trim($text);
	return $text;
}
?>
